@@ -14,7 +14,7 @@ from aiotfm.friend import Friend
 from aiotfm.message import Message, Whisper, Channel, ChannelMessage
 from aiotfm.shop import Shop
 from aiotfm.inventory import Inventory, InventoryItem, Trade
-from aiotfm.room import Room
+from aiotfm.room import Room, RoomList
 from aiotfm.enums import TradeError, Community
 from aiotfm.errors import AiotfmException, InvalidEvent, CommunityPlatformError, \
 	AlreadyConnected, IncorrectPassword, LoginError, ServerUnreachable
@@ -32,6 +32,9 @@ class Client:
 		Defines the community of the client. Defaults to 0 (EN community).
 	auto_restart: Optional[:class:`bool`]
 		Whether the client should automatically restart on error. Defaults to False.
+	bot_role: Optional[:class:`bool`]
+		Whether the has the game's special role bot or not.
+		Avoids using the api endpoint and gives more stability.
 	loop: Optional[event loop]
 		The `event loop`_ to use for asynchronous operations. If ``None`` is passed (defaults),
 		the event loop used will be ``asyncio.get_event_loop()``.
@@ -54,7 +57,7 @@ class Client:
 	"""
 	LOG_UNHANDLED_PACKETS = False
 
-	def __init__(self, community=Community.en, auto_restart=False, loop=None):
+	def __init__(self, community=Community.en, auto_restart=False, bot_role=False, loop=None):
 		self.loop = loop or asyncio.get_event_loop()
 
 		self.main = Connection('main', self, self.loop)
@@ -80,6 +83,8 @@ class Client:
 		self.api_token = None
 		self._restarting = False
 
+		self.bot_role = bot_role
+
 		self._channels = []
 
 	def data_received(self, data, connection):
@@ -282,6 +287,11 @@ class Client:
 			# :desc: Called when the client receives the ping response from the server.
 			self.dispatch('ping')
 
+		elif CCC == (26, 35): # Room list
+			roomlist = RoomList.from_packet(packet)
+			# :desc: Dispatched when the client receives the room list
+			self.dispatch('room_list', roomlist)
+
 		elif CCC == (28, 6): # Server ping
 			await connection.send(Packet.new(28, 6).write8(packet.read8()))
 
@@ -805,9 +815,11 @@ class Client:
 		Creates a connection with the main server.
 		"""
 
+		ip = "51.75.130.180" if self.bot_role else self.keys.server_ip
+
 		for port in random.sample([13801, 11801, 12801, 14801], 4):
 			try:
-				await self.main.connect(self.keys.server_ip, port)
+				await self.main.connect(ip, port)
 			except Exception:
 				pass
 			else:
@@ -822,7 +834,12 @@ class Client:
 		"""|coro|
 		Sends the handshake packet so the server recognizes this socket as a player.
 		"""
-		packet = Packet.new(28, 1).write16(self.keys.version).writeString(self.keys.connection)
+		packet = Packet.new(28, 1)
+		if self.bot_role:
+			packet.write16(666)
+		else:
+			packet.write16(self.keys.version).writeString(self.keys.connection)
+
 		packet.writeString('Desktop').writeString('-').write32(0x1fbd).writeString('')
 		packet.writeString('74696720697320676f6e6e61206b696c6c206d7920626f742e20736f20736164')
 		packet.writeString(
@@ -833,19 +850,21 @@ class Client:
 
 		await self.main.send(packet)
 
-	async def start(self, api_tfmid, api_token, keys=None):
+	async def start(self, api_tfmid=None, api_token=None, keys=None):
 		"""|coro|
 		Starts the client.
 
-		:param api_tfmid: :class:`int` or :class:`str` your Transformice id.
-		:param api_token: :class:`str` your token to access the API.
+		:param api_tfmid: Optional[:class:`int`] your Transformice id.
+		:param api_token: Optional[:class:`str`] your token to access the API.
 		"""
-		if keys is not None:
-			self.keys = keys
-		else:
-			self.api_tfmid = api_tfmid
-			self.api_token = api_token
-			self.keys = await get_keys(api_tfmid, api_token)
+
+		if not self.bot_role:
+			if keys is not None:
+				self.keys = keys
+			else:
+				self.api_tfmid = api_tfmid
+				self.api_token = api_token
+				self.keys = await get_keys(api_tfmid, api_token)
 
 		await self.connect()
 		await self.sendHandshake()
@@ -879,10 +898,11 @@ class Client:
 		self.main = Connection('main', self, self.loop)
 		self.bulle = None
 
-		if keys is not None:
-			self.keys = keys
-		else:
-			self.keys = keys = await get_keys(self.api_tfmid, self.api_token)
+		if not self.bot_role:
+			if keys is not None:
+				self.keys = keys
+			else:
+				self.keys = keys = await get_keys(self.api_tfmid, self.api_token)
 
 		await self.connect()
 		await self.sendHandshake()
@@ -902,13 +922,18 @@ class Client:
 
 		packet = Packet.new(26, 8).writeString(username).writeString(password)
 		packet.writeString("app:/TransformiceAIR.swf/[[DYNAMIC]]/2/[[DYNAMIC]]/4")
-		packet.writeString(room).write32(self.authkey ^ self.keys.auth).write8(0).writeString('')
-		packet.cipher(self.keys.identification).write8(0)
+		packet.writeString(room)
+		if not self.bot_role:
+			packet.write32(self.authkey ^ self.keys.auth)
+		packet.write8(0).writeString('')
+		if not self.bot_role:
+			packet.cipher(self.keys.identification)
+		packet.write8(0)
 
 		await self.main.send(packet)
 
 	def run(self, api_tfmid, api_token, username, password, **kwargs):
-		"""A blocking call that do the event loop initialization for you.
+		"""A blocking call that does the event loop initialization for you.
 
 		Equivalent to: ::
 			@bot.event
@@ -1022,13 +1047,12 @@ class Client:
 		"""|coro|
 		Get the client's friend list
 
-		:return: :class:`list`
-			List of friends
+		:return: List[:class:`aiotfm.Friend`]  List of friends
 		"""
 		await self.sendCP(28)
 
 		def is_friend_list(tc, packet):
-			return (tc == 34)
+			return tc == 34
 
 		tc, packet = await self.wait_for('on_raw_cp', is_friend_list)
 
@@ -1058,6 +1082,17 @@ class Client:
 				raise CommunityPlatformError(118, result)
 		return Tribe(packet)
 
+	async def getRoomList(self, gamemode=0):
+		"""|coro|
+		Get the room list
+
+		:param gamemode: Optional[:class:`aiotfm.enums.GameMode`] the room's gamemode.
+		:return: :class:`aiotfm.room.RoomList` the room list for the given gamemode
+		"""
+		await self.main.send(Packet.new(26, 35).write8(int(gamemode)))
+
+		return await self.wait_for('on_room_list', lambda r: r.gamemode == gamemode)
+
 	async def playEmote(self, emote, flag='be'):
 		"""|coro|
 		Play an emote.
@@ -1119,6 +1154,22 @@ class Client:
 		"""
 		await self.enterTribe()
 
+	async def enterInvTribeHouse(self, author):
+		"""|coro|
+		Join the tribe house of another player after receiving an /inv.
+
+		:param author: :class:`str` the author's username who sent the invitation.
+		"""
+		await self.main.send(Packet.new(16, 2).writeString(author))
+
+	async def recruit(self, player):
+		"""|coro|
+		Send a recruit request to a player.
+
+		:param player: :class:`str` the player's username you want to recruit.
+		"""
+		await self.sendCP(78, Packet().writeString(player))
+
 	async def joinRoom(self, room_name, password=None, community=None, auto=False):
 		"""|coro|
 		Join a room.
@@ -1163,22 +1214,6 @@ class Client:
 
 		await self.sendCP(56, Packet().writeString(name))
 
-	async def enterInvTribeHouse(self, author):
-		"""|coro|
-		Join the tribe house of another player after receiving an /inv.
-
-		:param author: :class:`str` the author's username who sent the invitation.
-		"""
-		await self.main.send(Packet.new(16, 2).writeString(author))
-
-	async def recruit(self, player):
-		"""|coro|
-		Send a recruit request to a player.
-
-		:param player: :class:`str` the player's username you want to recruit.
-		"""
-		await self.sendCP(78, Packet().writeString(player))
-
 	async def requestShopList(self):
 		"""|coro|
 		Send a request to the server to get the shop list."""
