@@ -1,4 +1,9 @@
 from aiotfm.errors import AiotfmException
+from aiotfm.enums import GameMode
+
+from collections import namedtuple
+
+RoomEntry = namedtuple('RoomEntry', 'community name player_count limit is_funcorp')
 
 
 class Room:
@@ -8,18 +13,18 @@ class Room:
 	----------
 	name: `str`
 		The room's name. (i.e: en-1, *bad girls and so on)
-	private: `bool`
-		Whether the room is public or private.
-	players: `list[aiotfm.player.Player]`
+	official: `bool`
+		Whether the room is an official room or not. If official, it's name will be displayed in yellow.
+	players: `list[:class:`aiotfm.Player`]`
 		The list containing all the players of the room.
 	"""
-	def __init__(self, name, private=True):
+	def __init__(self, name, official=False):
 		self.name = name
-		self.private = private
+		self.official = official
 		self.players = {}
 
 	def __repr__(self):
-		return "<Room name={} private={}>".format(self.name, self.private)
+		return "<Room name={} official={}>".format(self.name, self.official)
 
 	@property
 	def community(self):
@@ -56,7 +61,7 @@ class Room:
 		"""Gets one player in the room with an identifier.
 
 		:param kwargs: Which identifier to use. Can be either name, username, id or pid.
-		:return: :class:`aiotfm.player.Player` The player or None"""
+		:return: :class:`aiotfm.Player` The player or None"""
 		length = len(kwargs.keys())
 
 		if length == 0:
@@ -80,4 +85,55 @@ class Room:
 		for player in self.players.values():
 			if filter_(player):
 				return player
-		return default
\ No newline at end of file
+		return default
+
+
+class RoomList:
+	"""Represents the list of rooms in the server.
+
+	Attributes
+	----------
+	gamemode: :class:`aiotfm.enums.GameMode`
+		The list's gamemode.
+	rooms: List[`RoomEntry`]
+		The list of normal rooms.
+	pinned_rooms: List[`RoomEntry`]
+		The list of pinned(/module) rooms.
+	gamemodes: List[:class:`aiotfm.enums.GameMode`]
+		The list of gamemodes available.
+	"""
+	def __init__(self, gamemode, rooms, pinned_rooms, gamemodes):
+		self.gamemode = gamemode
+		self.rooms = rooms
+		self.pinned_rooms = pinned_rooms
+		self.gamemodes = gamemodes
+
+	@classmethod
+	def from_packet(cls, packet):
+		gamemodes = [GameMode(packet.read8()) for _ in range(packet.read8())]
+		gamemode = GameMode(packet.read8())
+		rooms = []
+		pinned = []
+
+		while packet.pos < len(packet.buffer):
+			is_pinned = packet.readBool()
+			community = packet.read8()
+			name = packet.readUTF()
+
+			if is_pinned:
+				player_count = packet.readUTF()
+				packet.readUTF() # command
+				packet.readUTF() # command arg
+
+				if player_count.isdigit():
+					player_count = int(player_count)
+
+				pinned.append(RoomEntry(community, name, player_count, 0, False))
+			else:
+				player_count = packet.read16()
+				limit = packet.read8()
+				is_funcorp = packet.readBool()
+
+				rooms.append(RoomEntry(community, name, player_count, limit, is_funcorp))
+
+		return cls(gamemode, rooms, pinned, gamemodes)
\ No newline at end of file
